@@ -261,7 +261,10 @@ def browse(card, cards, reviewing = False):
 		if k in CMD_DICT:
 			ansi.show_cursor()
 			card = cards[sel] if k in ('x','s','r','R','e','E', 't') else None
-			CMD_DICT[k](card, cards)
+			if k == 'e':
+				edit(card)
+			else:
+				CMD_DICT[k](card, cards)
 			ansi.hide_cursor()
 			reviewing = (k == 'R' and cards[sel].last_grade != 'exit')
 			if reviewing and sel == N - 1:
