@@ -1,13 +1,12 @@
 from vinca.lib import classes
 from vinca.lib import ansi
 
-def generate(args):
+def generate(scrollback = True):
 	new_card = classes.Card(create=True)
 	new_card.editor, new_card.reviewer, new_card.scheduler = 'two_lines', 'two_lines', 'base'
-	front = input('Q:   ')
-	back = input('A:   ')
-	(new_card.path/'front').write_text(front)
-	(new_card.path/'back').write_text(back)
-	if args.scrollback:
+	(new_card.path / 'front').touch()
+	(new_card.path / 'back').touch()
+	new_card.edit()
+	if scrollback:
 		ansi.up_line(2)
 	return [new_card]
